@@ -1,3 +1,7 @@
+""":mod:`earthreader.web.command` --- Command interface
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+"""
 from __future__ import print_function
 
 import argparse
@@ -13,10 +17,10 @@ from libearth.stage import Stage
 from sassutils.wsgi import SassMiddleware
 from waitress import serve
 
-from .app import app, spawn_worker
+from . import app
 from .util import autofix_repo_url
 
-__all__ = 'crawl', 'main', 'server'
+__all__ = 'crawl', 'main'
 
 
 def crawl_command(args):
@@ -55,7 +59,8 @@ def crawl_command(args):
                 feed_id = feed_map[feed_url]
                 stage.feeds[feed_id] = feed_data
         except (CrawlError, SchemaError) as e:
-            print('Something went wrong with', feed_url, file=sys.stderr)
+            if isinstance(e, CrawlError):
+                print('Something went wrong with', e.feed_uri, file=sys.stderr)
             if args.verbose:
                 traceback.print_exc()
             else:
@@ -68,6 +73,8 @@ def server_command(args):
     repository = args.repository
     app.config.update(REPOSITORY=repository, SESSION_ID=args.session_id)
     app.debug = args.debug
+    if args.no_worker:
+        app.config.update(USE_WORKER=False)
     if args.profile:
         try:
             from linesman.middleware import make_linesman_middleware
@@ -81,12 +88,12 @@ def server_command(args):
             print('Profiler (linesman) is available:',
                   'http://{0.host}:{0.port}/__profiler__/'.format(args))
         app.wsgi_app = make_linesman_middleware(app.wsgi_app)
-    spawn_worker()
     if args.debug:
         app.wsgi_app = SassMiddleware(app.wsgi_app, {
             'earthreader.web': ('static/scss/', 'static/css/')
         })
-        app.run(host=args.host, port=args.port, debug=args.debug, threaded=True)
+        app.run(host=args.host, port=args.port, debug=args.debug,
+                threaded=True)
     else:
         serve(app, host=args.host, port=args.port)
 
@@ -103,7 +110,8 @@ server_parser.add_argument('-H', '--host',
 server_parser.add_argument('-p', '--port',
                            type=int,
                            default=5000,
-                           help='port number to listen. [default: %(default)s]')
+                           help='port number to listen.'
+                                '[default: %(default)s]')
 server_parser.add_argument('-d', '--debug',
                            default=False,
                            action='store_true',
@@ -117,6 +125,10 @@ server_parser.add_argument('-P', '--profile', '--linesman',
                            action='store_true',
                            help="profile using linesman.  it's available only "
                                 'when linesman is installed')
+server_parser.add_argument('-w', '--no-worker',
+                           default=False,
+                           action='store_true',
+                           help='Disable worker thread that crawl feeds')
 server_parser.add_argument('repository', help='repository for Earth Reader')
 
 crawl_parser = subparsers.add_parser('crawl', help='crawl feeds in the opml')
@@ -127,8 +139,8 @@ crawl_parser.add_argument('-n', '--threads',
 crawl_parser.add_argument('-i', '--session-id',
                           default=Session().identifier,
                           help='session identifier.  [default: %(default)s]')
-crawl_parser.add_argument('-v', '--verbose', default=False, action='store_true',
-                          help='verbose mode')
+crawl_parser.add_argument('-v', '--verbose', default=False,
+                          action='store_true', help='verbose mode')
 crawl_parser.add_argument('-f', '--feed-id',
                           help='crawl only the specified feed.  '
                                'crawl all subscriptions by default')
